function varargout = MotionAnalyst_about(varargin)
% MotionAnalyst_about M-file for MotionAnalyst_about.fig
% Author:	Robb Colbrunn, Cleveland Clinc BioRobotics and Mechanical Testing Core
% Date:		2-10-10
% Last change:  3-24-11
% Version:	1.3
% See documentation for complete change history
%      MotionAnalyst_about, by itself, creates a new MotionAnalyst_about or raises the existing
%      singleton*.
%
%      H = MotionAnalyst_about returns the handle to a new MotionAnalyst_about or the handle to
%      the existing singleton*.
%
%      MotionAnalyst_about('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MotionAnalyst_about.M with the given input arguments.
%
%      MotionAnalyst_about('Property','Value',...) creates a new MotionAnalyst_about or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before MotionAnalyst_about_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to MotionAnalyst_about_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help MotionAnalyst_about

% Last Modified by GUIDE v2.5 24-Mar-2011 13:57:43

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @MotionAnalyst_about_OpeningFcn, ...
                   'gui_OutputFcn',  @MotionAnalyst_about_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before MotionAnalyst_about is made visible.
function MotionAnalyst_about_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to MotionAnalyst_about (see VARARGIN)

% Choose default command line output for MotionAnalyst_about
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes MotionAnalyst_about wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = MotionAnalyst_about_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in Help.
function Help_Callback(hObject, eventdata, handles)
% hObject    handle to Help (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
open('MotionAnalyst_help.pdf');
